@@ -27,18 +27,18 @@
 
 #include <gal/e-table/e-table.h>
 #include <gal/e-table/e-tree.h>
-#include <libgnomeui/gnome-canvas.h>
-#include <tree.h>
+#include <libgnomecanvas/gnome-canvas.h>
+#include <libxml/tree.h>
 #include <gal/e-table/e-table-header.h>
 #include <gal/e-table/e-table-sort-info.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_TABLE_HEADER_ITEM_TYPE        (e_table_header_item_get_type ())
-#define E_TABLE_HEADER_ITEM(o)          (GTK_CHECK_CAST ((o), E_TABLE_HEADER_ITEM_TYPE, ETableHeaderItem))
-#define E_TABLE_HEADER_ITEM_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TABLE_HEADER_ITEM_TYPE, ETableHeaderItemClass))
-#define E_IS_TABLE_HEADER_ITEM(o)       (GTK_CHECK_TYPE ((o), E_TABLE_HEADER_ITEM_TYPE))
-#define E_IS_TABLE_HEADER_ITEM_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TABLE_HEADER_ITEM_TYPE))
+#define E_TABLE_HEADER_ITEM(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TABLE_HEADER_ITEM_TYPE, ETableHeaderItem))
+#define E_TABLE_HEADER_ITEM_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_TABLE_HEADER_ITEM_TYPE, ETableHeaderItemClass))
+#define E_IS_TABLE_HEADER_ITEM(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TABLE_HEADER_ITEM_TYPE))
+#define E_IS_TABLE_HEADER_ITEM_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_TABLE_HEADER_ITEM_TYPE))
 
 typedef struct {
 	GnomeCanvasItem  parent;
@@ -84,6 +84,13 @@ typedef struct {
 	 */
 	ETableSortInfo  *sort_info;
 	
+	guint scroll_direction : 4;
+	int last_drop_x;
+	int last_drop_y;
+	int last_drop_time;
+	GdkDragContext *last_drop_context;
+	int scroll_idle_id;
+
 	/* For adding fields. */
 	ETableHeader    *full_header;
 	ETable          *table;
@@ -100,8 +107,8 @@ typedef struct {
 	void (*button_pressed) (ETableHeaderItem *ethi, GdkEventButton *button);
 } ETableHeaderItemClass;
 
-GtkType    e_table_header_item_get_type (void);
+GType      e_table_header_item_get_type (void);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_TABLE_HEADER_ITEM_H_ */
