@@ -480,7 +480,7 @@ et_search_search (ETableSearch *search, char *string, ETableSearchFlags flags, E
 
 	cursor = e_tree_get_cursor (et);
 
-	if (flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST) {
+	if (cursor && (flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST)) {
 		const void *value;
 
 		value = e_tree_model_value_at (et->priv->model, cursor, col->col_idx);
@@ -504,7 +504,7 @@ et_search_search (ETableSearch *search, char *string, ETableSearchFlags flags, E
 
 		e_selection_model_select_as_key_press(E_SELECTION_MODEL (et->priv->selection), model_row, col->col_idx, GDK_CONTROL_MASK);
 		return TRUE;
-	} else if (!(flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST)) {
+	} else if (cursor && !(flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST)) {
 		const void *value;
 
 		value = e_tree_model_value_at (et->priv->model, cursor, col->col_idx);
@@ -1344,18 +1344,6 @@ et_table_cell_changed (ETableModel *table_model, int view_col, int row, ETree *e
 	et_table_model_changed (table_model, et);
 }
 
-static void
-et_table_rows_inserted (ETableModel *table_model, int row, int count, ETree *et)
-{
-	et_table_model_changed (table_model, et);
-}
-
-static void
-et_table_rows_deleted (ETableModel *table_model, int row, int count, ETree *et)
-{
-	et_table_model_changed (table_model, et);
-}
-
 static void
 et_connect_to_etta (ETree *et)
 {
@@ -1368,12 +1356,6 @@ et_connect_to_etta (ETree *et)
 	et->priv->table_cell_change_id = g_signal_connect (et->priv->etta, "model_cell_changed",
 							   G_CALLBACK (et_table_cell_changed), et);
 
-	et->priv->table_rows_inserted_id = g_signal_connect (et->priv->etta, "model_rows_inserted",
-							     G_CALLBACK (et_table_rows_inserted), et);
-
-	et->priv->table_rows_deleted_id = g_signal_connect (et->priv->etta, "model_rows_deleted",
-							    G_CALLBACK (et_table_rows_deleted), et);
-
 }
 
 static ETree *
